You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@impala.apache.org by ta...@apache.org on 2020/04/21 19:28:42 UTC

[impala] branch master updated: IMPALA-9683: distcc ubuntu 18.04 support

This is an automated email from the ASF dual-hosted git repository.

tarmstrong pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/impala.git


The following commit(s) were added to refs/heads/master by this push:
     new 2dc2006  IMPALA-9683: distcc ubuntu 18.04 support
2dc2006 is described below

commit 2dc2006c9ea09f9f83815aa5a450d6d95b2d8b1c
Author: Tim Armstrong <ta...@cloudera.com>
AuthorDate: Tue Apr 21 10:51:18 2020 -0700

    IMPALA-9683: distcc ubuntu 18.04 support
    
    This allows distcc server bootstraping on Ubuntu 18.04.
    I ran the script on Ubuntu 18.04 and it worked without
    modifications.
    
    Change-Id: I0deb31663a9ba96143191bc3d7eb2884e382260e
    Reviewed-on: http://gerrit.cloudera.org:8080/15772
    Reviewed-by: Joe McDonnell <jo...@cloudera.com>
    Tested-by: Tim Armstrong <ta...@cloudera.com>
---
 bin/distcc/distcc_server_bootstrap.sh | 4 ++--
 bin/distcc/distcc_server_setup.sh     | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/bin/distcc/distcc_server_bootstrap.sh b/bin/distcc/distcc_server_bootstrap.sh
index 2f931f5..fd69a56 100755
--- a/bin/distcc/distcc_server_bootstrap.sh
+++ b/bin/distcc/distcc_server_bootstrap.sh
@@ -36,8 +36,8 @@ fi
 LSB_ID=$(lsb_release -is)
 LSB_VERSION=$(lsb_release -rs)
 if [[ "$LSB_ID" == Ubuntu ]]; then
-  if ! [[ $LSB_VERSION == 16.04 ]]; then
-    echo "This script only supports Ubuntu 16.04" >&2
+  if ! [[ $LSB_VERSION == 16.04 || $LSB_VERSION == 18.04 ]]; then
+    echo "This script only supports Ubuntu 16.04 and 18.04" >&2
     exit 1
   fi
 fi
diff --git a/bin/distcc/distcc_server_setup.sh b/bin/distcc/distcc_server_setup.sh
index 83bce46..38a93dc 100755
--- a/bin/distcc/distcc_server_setup.sh
+++ b/bin/distcc/distcc_server_setup.sh
@@ -18,8 +18,8 @@
 # under the License.
 
 # This script automates setup of distcc servers on Ubuntu and CentOS. It has been tested
 # on Ubuntu 14.04 and 16.04 and CentOS 6 and 7. See bin/distcc/README.md for manual setup
 # instructions and background.
 #
 # Usage:
 # ------
@@ -60,8 +60,8 @@ ALLOWED_NETS=$1
 LSB_ID=$(lsb_release -is)
 LSB_VERSION=$(lsb_release -rs)
 if [[ "$LSB_ID" == Ubuntu ]]; then
-  if ! [[ $LSB_VERSION == 14.04 || $LSB_VERSION == 16.04 ]]; then
-    echo "This script only supports Ubuntu 14.04 and 16.04" >&2
+  if ! [[ $LSB_VERSION == 14.04 || $LSB_VERSION == 16.04 || $LSB_VERSION == 18.04 ]]; then
+    echo "This script only supports Ubuntu 14.04, 16.04 and 18.04" >&2
     exit 1
   fi
   LINUX_FLAVOUR=ubuntu
@@ -18,8 +18,8 @@
 
 # This script automates setup of distcc servers on Ubuntu and CentOS. It has been tested
-# on Ubuntu 14.04 and 16.04 and CentOS 6 and 7. See bin/distcc/README.md for manual setup
-# instructions and background.
+# on Ubuntu 14.04, 16.04 and 18.04 and CentOS 6 and 7. See bin/distcc/README.md for manual
+# setup instructions and background.
 #
 # Usage: